"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.calculatePricingInformation = void 0;
var geo_shipping_prices_1 = require("@uppfirst/geo-shipping-prices");
var convertToFloat = function (value, decimals) {
    return parseFloat((value / Math.pow(10, decimals)).toFixed(decimals));
};
var calculateShippingPrices = function (_a) {
    var _b, _c;
    var product = _a.product, stateCode = _a.stateCode, countryCode = _a.countryCode;
    var shipping = product.shipping;
    if (!shipping || !countryCode) {
        return {
            taxCost: 0,
            taxPercent: 0,
            shippingCost: 0,
        };
    }
    var shippingCalculator = new geo_shipping_prices_1.Shipping(shipping);
    var prices = stateCode && countryCode === 'US'
        ? shippingCalculator.state(stateCode)
        : shippingCalculator.country(countryCode);
    var taxPercent = ((_b = prices.prices) === null || _b === void 0 ? void 0 : _b.tax) || 0;
    var shippingCost = ((_c = prices.prices) === null || _c === void 0 ? void 0 : _c.price) || 0;
    return {
        taxCost: (taxPercent / 100) * product.price,
        taxPercent: taxPercent,
        shippingCost: shippingCost * 100,
    };
};
var calculatePricingInformation = function (_a) {
    var product = _a.product, countryCode = _a.countryCode, stateCode = _a.stateCode, combination = _a.combination, usedRewards = _a.usedRewards;
    var startAmountPercent = product.startAmountPercent / 100;
    var rewardShare = product.rewardShare / 100;
    var claimPercent = 1 - startAmountPercent;
    var traitCost = ((combination === null || combination === void 0 ? void 0 : combination.price) || 0) * 100;
    var baseReserve = product.price * startAmountPercent;
    var baseClaim = product.price * claimPercent;
    var gainedRewardsReserve = rewardShare * baseReserve;
    var gainedRewardsClaim = rewardShare * baseClaim;
    var totalBase = product.price;
    var _b = calculateShippingPrices({
        product: product,
        countryCode: countryCode,
        stateCode: stateCode,
    }), shippingCost = _b.shippingCost, taxCost = _b.taxCost, taxPercent = _b.taxPercent;
    var usedRewardsTotal = usedRewards.reduce(function (acc, reward) { return acc + reward.price; }, 0);
    console.log(baseReserve, traitCost, taxCost, shippingCost, usedRewardsTotal);
    return {
        startAmountPercent: product.startAmountPercent,
        usedRewardsTotal: convertToFloat(usedRewardsTotal, product.currency.decimals),
        reserve: {
            base: convertToFloat(baseReserve, product.currency.decimals),
            traitCost: convertToFloat(traitCost, product.currency.decimals),
            gainedRewardsAmount: convertToFloat(gainedRewardsReserve, product.currency.decimals),
            taxPercent: taxPercent,
            shippingCost: convertToFloat(shippingCost, product.currency.decimals),
            taxCost: convertToFloat(taxCost, product.currency.decimals),
            total: convertToFloat(Math.max(baseReserve + traitCost + taxCost + shippingCost - usedRewardsTotal, 0), product.currency.decimals),
        },
        claim: {
            base: convertToFloat(baseClaim, product.currency.decimals),
            gainedRewardsAmount: convertToFloat(gainedRewardsClaim, product.currency.decimals),
            total: convertToFloat(Math.max(baseClaim - usedRewardsTotal), product.currency.decimals),
        },
        total: {
            base: convertToFloat(totalBase, product.currency.decimals),
            gainedRewardsAmount: convertToFloat(gainedRewardsReserve + gainedRewardsClaim, product.currency.decimals),
            total: convertToFloat(Math.max(totalBase + taxCost + shippingCost - usedRewardsTotal, 0), product.currency.decimals),
        },
    };
};
exports.calculatePricingInformation = calculatePricingInformation;
